@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,37 +19,33 @@
 #ifndef LOGID_BACKEND_HIDPP_DEFS_H
 #define LOGID_BACKEND_HIDPP_DEFS_H
 
-#define LOGID_HIDPP_SOFTWARE_ID 0
-
 #include <cstdint>
 
-namespace logid {
-namespace backend {
-namespace hidpp
-{
-    namespace ReportType
-    {
-        enum ReportType : uint8_t
-        {
+namespace logid::backend::hidpp {
+    namespace ReportType {
+        enum ReportType : uint8_t {
             Short = 0x10,
             Long = 0x11
         };
     }
 
-    enum DeviceIndex: uint8_t
-    {
+    enum DeviceIndex : uint8_t {
         DefaultDevice = 0xff,
         CordedDevice = 0,
         WirelessDevice1 = 1,
-        WirelessDevice2 = 2,
-        WirelessDevice3 = 3,
-        WirelessDevice4 = 4,
-        WirelessDevice5 = 5,
+        WirelessDevice2 [[maybe_unused]] = 2,
+        WirelessDevice3 [[maybe_unused]] = 3,
+        WirelessDevice4 [[maybe_unused]] = 4,
+        WirelessDevice5 [[maybe_unused]] = 5,
         WirelessDevice6 = 6,
     };
 
+    static constexpr uint8_t softwareID = 2;
+    /* For sending reports with no response, use a different SW ID */
+    static constexpr uint8_t noAckSoftwareID = 1;
+
     static constexpr std::size_t ShortParamLength = 3;
     static constexpr std::size_t LongParamLength = 16;
-} } }
+}
 
 #endif //LOGID_BACKEND_HIDPP_DEFS_H
\ No newline at end of file
