@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,16 +15,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#include "Reset.h"
+#include <backend/hidpp20/features/Reset.h>
 
 using namespace logid::backend::hidpp20;
 
-Reset::Reset(Device *device) : Feature(device, ID)
-{
+Reset::Reset(Device* device) : Feature(device, ID) {
 }
 
-uint16_t Reset::getProfile()
-{
+uint16_t Reset::getProfile() {
     std::vector<uint8_t> params(0);
     auto results = callFunction(GetProfile, params);
 
@@ -33,8 +31,7 @@ uint16_t Reset::getProfile()
     return profile;
 }
 
-void Reset::reset(uint16_t profile)
-{
+void Reset::reset(uint16_t profile) {
     std::vector<uint8_t> params(2);
     params[0] = (profile >> 8) & 0xff;
     params[1] = profile & 0xff;
