@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,33 +15,30 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#include "SmartShift.h"
+#include <backend/hidpp20/features/SmartShift.h>
 
 using namespace logid::backend::hidpp20;
 
-SmartShift::SmartShift(Device* dev) : Feature(dev, ID)
-{
+SmartShift::SmartShift(Device* dev) : Feature(dev, ID) {
 }
 
-SmartShift::SmartshiftStatus SmartShift::getStatus()
-{
+SmartShift::SmartshiftStatus SmartShift::getStatus() {
     std::vector<uint8_t> params(0);
     SmartshiftStatus status{};
     auto response = callFunction(GetStatus, params);
-    status.active = response[0]-1;
+    status.active = response[0] - 1;
     status.autoDisengage = response[1];
     status.defaultAutoDisengage = response[2];
     return status;
 }
 
-void SmartShift::setStatus(SmartshiftStatus status)
-{
+void SmartShift::setStatus(SmartshiftStatus status) {
     std::vector<uint8_t> params(3);
-    if(status.setActive)
+    if (status.setActive)
         params[0] = status.active + 1;
-    if(status.setAutoDisengage)
+    if (status.setAutoDisengage)
         params[1] = status.autoDisengage;
-    if(status.setDefaultAutoDisengage)
+    if (status.setDefaultAutoDisengage)
         params[2] = status.defaultAutoDisengage;
     callFunction(SetStatus, params);
 }
\ No newline at end of file
